import { PromiseFn } from './types';
/**
 * An asynchronous wrapping function, that enables use of async functions within
 * React functional components. This hook handles the entire lifecycle of a promise.
 *
 * (?) When the promise is executing, calling it again will result in the previous
 *     execution being ignored. Eg.: the last call to run / runAsync will always be
 *     the one that is affecting the state.
 */
export interface UseAsyncState<Res, Err> {
    isLoading: boolean;
    isCompleted: boolean;
    isSucceed: boolean;
    isFailed: boolean;
    result?: Res;
    error?: Err;
}
export interface UseAsyncReturn<Res = void, Args extends any[] = [], Err = any> extends UseAsyncState<Res, Err> {
    run: (...args: Args) => void;
    runAsync: PromiseFn<Args, Res>;
}
export declare function useAsync<Res = void, Args extends any[] = [], Err = any>(fn: PromiseFn<Args, Res>): UseAsyncReturn<Res, Args, Err>;
