var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useCallback, useRef } from 'react';
import { ConcurrencyError } from './types';
import { useLatest } from '../generic/useLatest';
/**
 * Wraps an async function such that only one call at-a-time may be in execution,
 * any attempt to call the promise while another execution is in progress
 * will result in the second call throwing an exception.
 *
 * (!) Promise should be stable, changing promise while a call is in progress
 * will not affect the outcome nor interrupt the execution.
 *
 * (?) Returned task is assured to be stable, an old result instance will
 * always call the most fresh task.
 *
 * /B 2022-10-19
 */
export function useExclusivePromise(fn) {
    const lastFn = useLatest(fn);
    const isExecuting = useRef(false);
    return useCallback((...args) => __awaiter(this, void 0, void 0, function* () {
        if (isExecuting.current) {
            throw new ConcurrencyError(`Promise is already running`);
        }
        else {
            isExecuting.current = true;
            const res = yield lastFn.current.apply(undefined, args);
            isExecuting.current = false;
            return res;
        }
    }), []);
}
