import { PromiseFn } from './types';
/**
 * Joins multiple promise call into one, only one promise will be running
 * at-a-time, calls are not queued but rather joined. When promises are
 * called with arguments if arguments are the same as the original call
 * the promise will be joined and wait for the completion, if arguments
 * are different the promise will throw a concurrency exception.
 *
 * (?) Arguments are shallow compared with Object.is
 * (same strategy that is used by React on effect dependencies)
 *
 * (!) Task should be stable, changing task while a call is in progress
 * will not affect the outcome nor interrupt the execution.
 *
 * (?) Returned task is assured to be stable, an old result instance will
 * always call the most fresh task.
 *
 * todo : if fn includes states that change a sequence such is:
 *      call() -> setState() -> call() ...... return
 *      may return unexpected values to the the second call.
 *
 * /B 2022-10-19
 */
export declare function useSharedPromise<Res, Args extends any[] = []>(fn: PromiseFn<Args, Res>): PromiseFn<Args, Res>;
