import { useEffect, useRef } from 'react';
import { useLatest } from '../generic/useLatest';
export function useScheduledEffect(fn, at, deps, options) {
    const latestFn = useLatest(fn);
    const hasRun = useRef(false);
    useEffect(() => {
        // Skip
        if (at === undefined || hasRun.current)
            return undefined;
        // Coerce
        const unix = typeof at === 'number' ? at : at.getTime();
        const now = Date.now();
        if (unix <= now) {
            // Run now
            if ((options === null || options === void 0 ? void 0 : options.maximumExpiration) === undefined || (now - unix) < (options === null || options === void 0 ? void 0 : options.maximumExpiration)) {
                latestFn.current();
                hasRun.current = true;
            }
            return undefined;
        }
        else {
            // Schedule for future
            const tm = setTimeout(() => latestFn.current(), unix - now);
            return () => clearTimeout(tm);
        }
    }, [at, ...(deps || [])]);
}
