import { useGlobalTag } from '../dom/useGlobalTag';
/**
 * File select hook. Returns an async function which upon call will initiate a native
 * file selection modal and resolve upon selection completion.
 *
 * const select = useFileSelect({ multiple: true, accept: ['csv', 'xslx' ] })
 *
 */
export function useFileSelect(props) {
    // Create a hidden input field with all the expected configs
    const ref = useGlobalTag('input', el => {
        el.setAttribute('type', 'file');
        (props === null || props === void 0 ? void 0 : props.multiple)
            ? el.setAttribute('multiple', 'true')
            : el.removeAttribute('multiple');
        (props === null || props === void 0 ? void 0 : props.accept) && el.setAttribute('accept', props.accept.join(','));
        (props === null || props === void 0 ? void 0 : props.capture) && el.setAttribute('capture', props.capture);
    });
    return () => {
        return new Promise(resolve => {
            if (!ref.current) {
                resolve(undefined);
            }
            else {
                ref.current.addEventListener('change', (event) => resolve(event.target.files
                    ? Array.from(event.target.files)
                    : undefined), { once: true });
                ref.current.click();
            }
        });
    };
}
