import { getStorage } from './storage';
import { useStorage } from './useStorage';
import { useEvent } from '../dom/useEvent';
import { useLatest } from '../generic/useLatest';
/**
 * Same as useStorage() but does enable dynamic storage updates by
 * subscribing to the window `storage` event.
 *
 * /B 2022-10-19
 */
export function useReactiveStorage(initialState, prefix = '', storage = 'localStorage') {
    const [state, setState] = useStorage(initialState, prefix, storage);
    const ctx = useLatest({ prefix, storage });
    useEvent('storage', event => {
        var _a;
        const c = ctx.current;
        if (((_a = event.key) === null || _a === void 0 ? void 0 : _a.startsWith(c.prefix)) && event.storageArea === getStorage(c.storage)) {
            setState(last => (Object.assign(Object.assign({}, last), { [event.key.substring(c.prefix.length)]: event.newValue })));
        }
    });
    return [state, setState];
}
