import { Dispatch, SetStateAction } from 'react';
import { MultiValue, StorageTypes } from './storage';
/**
 * Offers an abstraction layer atop SessionStorage and LocalStorage.
 * This hook expects an objects as its state and stores each key of
 * the object as a JSON ENCODED value.
 *
 * (?) Optionally prefix can be provided to prefix each object key
 *     inside the underlying storage (to prevent collisions)
 *
 * (?) Optionally an initial value can be provided that will be used
 *     when no key for the given prefix will be detected in the store.
 *     Keep in mind that store keys may be anyhow deleted, so never
 *     give for granted their presence (not their pairwise presence)
 *
 * /B 2022-10-19
 */
export declare function useStorage<S extends MultiValue>(initialState?: S | (() => S), prefix?: string, storage?: StorageTypes): [S, Dispatch<SetStateAction<S>>];
